@@ -15,11 +15,12 @@
 # $Date: 2011-07-10 19:09:53 +0800 (週日, 10 七月 2011) $
 # $Revision: 5524 $
 
+#!/usr/bin/env python
 import os
 import sys
 
 if __name__ == "__main__":
-    os.environ.setdefault("DJANGO_SETTINGS_MODULE", "settings")
+    os.environ.setdefault("DJANGO_SETTINGS_MODULE", "mail.settings")
 
     from django.core.management import execute_from_command_line
 
