@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Util.py 9439 2015-09-25 08:01:30Z Eric $
+# $Id: Util.py 9927 2017-04-29 14:17:02Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,13 +11,58 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Eric $ (last)
-# $Date: 2015-09-25 16:01:30 +0800 (Fri, 25 Sep 2015) $
-# $Revision: 9439 $
+# $Author: David $ (last)
+# $Date: 2017-04-29 22:17:02 +0800 (Sat, 29 Apr 2017) $
+# $Revision: 9927 $
 """
 Utilities.
 """
 
+def update(settingsDict, defaults, config=None):
+    """
+    Update settings by defaults if the key is not in settings.
+    
+    @param settingsDict Settings dict.
+    @param defaults Defaults dict to provide default value.
+    @param config Reserved.
+    """
+    for k, v in defaults.items():
+        if k not in settingsDict:
+            settingsDict[k] = v
+
+def populateEnvToSettings(keys, settingsDict, setter=None, evalKeys=None):
+    """
+    Populate value in environment variables to settings.
+
+    @param keys Variable keys to find in environment variables.
+    @param settingsDict locals() in settings.py.
+    @param setter Function to decide how to set to settings.
+    @param evalKeys The keys in keys arguments which its value should be eval.
+    @return Set keys.
+    """
+    setKeys = []
+
+    import os
+    from Iuppiter.Util import colored
+    
+    for k in keys:
+        if k in os.environ:
+            print "%s found in environment variable, set to settings." % (
+                colored(k, 'yellow', attrs=['bold']))
+            
+            v = os.environ[k]
+            if evalKeys and k in evalKeys:
+                v = eval(v)
+                
+            if setter:
+                setter(k, v, settingsDict)
+            else:
+                settingsDict[k] = v
+                
+            setKeys.append(k)
+            
+    return setKeys
+
 class VersionInfo(object):
     def __init__(self, version='',
                  major=None, minor=None, build=None, revision=None):
