@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 10057 2017-06-18 15:16:01Z David $
+# $Id: urls.py 10096 2017-07-11 11:03:58Z David $
 #
-# Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
+# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
 # Licensed under the Proprietary License,
 # you may not use this file except in compliance with the License.
@@ -12,20 +12,27 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-06-18 23:16:01 +0800 (Sun, 18 Jun 2017) $
-# $Revision: 10057 $
+# $Date: 2017-07-11 19:03:58 +0800 (Tue, 11 Jul 2017) $
+# $Revision: 10096 $
 
 from django.conf.urls import include, url
-from views import *
+
+from views import (
+    SignupView, LoginView, ConfirmEmailView, ChangePasswordView, LogoutView,
+    PasswordResetView, PasswordResetTokenView, SettingsView, DeleteView
+)
 
 urlpatterns = [
     url(r"^signup/$", SignupView.as_view(), name="account_signup"),
     url(r"^login/$", LoginView.as_view(), name="account_login"),
     url(r"^logout/$", LogoutView.as_view(), name="account_logout"),
-    url(r"^confirm_email/(?P<key>\w+)/$", ConfirmEmailView.as_view(), name="account_confirm_email"),
+    url(r"^confirm_email/(?P<key>\w+)/$", 
+        ConfirmEmailView.as_view(), name="account_confirm_email"),
     url(r"^password/$", ChangePasswordView.as_view(), name="account_password"),
-    url(r"^password/reset/$", PasswordResetView.as_view(), name="account_password_reset"),
-    url(r"^password/reset/(?P<uidb36>[0-9A-Za-z]+)-(?P<token>.+)/$", PasswordResetTokenView.as_view(), name="account_password_reset_token"),
+    url(r"^password/reset/$", PasswordResetView.as_view(), 
+        name="account_password_reset"),
+    url(r"^password/reset/(?P<uidb36>[0-9A-Za-z]+)-(?P<token>.+)/$", 
+        PasswordResetTokenView.as_view(), name="account_password_reset_token"),
     url(r"^settings/$", SettingsView.as_view(), name="account_settings"),
     url(r"^delete/$", DeleteView.as_view(), name="account_delete"),
     url('', include('social_django.urls', namespace='social')),
