@@ -14,9 +14,12 @@
 # $Author: David $ (last)
 # $Date: 2017-02-08 09:01:19 +0800 (Wed, 08 Feb 2017) $
 # $Revision: 9742 $
-import Iuno
+
+import os
 from django.test import TestCase
 
+from Iuno import shop
+
 class TestAttachSettings(TestCase):
     
     def runTest(self):
@@ -44,6 +47,17 @@ class TestAttachSettings(TestCase):
 
             "ROOT_URLCONF": 'TemplatesShop.urls',
 
+            'DATABASES': {
+                'default': {
+                    'ENGINE': 'django.db.backends.sqlite3',
+                    'NAME': os.path.join('BASE_DIR', 'db.sqlite3'),
+                }
+            },
+
+            "DEBUG": True,
+
+            '__file__': '/Users/Ming/Documents/Nuwa_mercurius/Projects/TemplatesShop/TemplatesShop/settings.pyc',
+
             "TEMPLATES": [
                 {
                     'BACKEND': 'django.template.backends.django.DjangoTemplates',
@@ -60,44 +74,44 @@ class TestAttachSettings(TestCase):
                 },
             ],
 
-            "__file__": '/Users/Ming/Documents/Nuwa_mercurius/Projects/TemplatesShop/TemplatesShop/settings.pyc',
+            'DEFAULT_FROM_EMAIL': 'test@nuwainfo.com',
+            'BASE_DIR': 'ddd'
         }
-
-
         
-         # Iuno.shop 
-        IUNO_SHOP_ENABLE = True
-        Iuno.attachSettings(settingsContent)
+        shop.attachSettings(settingsContent)
         
-        templatesSettings = {
-            'TEMPLATES' : [
-                {
-                    'BACKEND': 'django.template.backends.django.DjangoTemplates',
-                    'DIRS': [os.path.join(BASE_DIR, 'templates'),
-                            
-                            OSCAR_MAIN_TEMPLATE_DIR, ],
-                    'APP_DIRS': True,
-                    'OPTIONS': {
-                        'context_processors': [
-                            'django.template.context_processors.debug',
-                            'django.template.context_processors.request',
-                            'django.contrib.auth.context_processors.auth',
-                            'django.contrib.messages.context_processors.messages',
-                            
-                            'oscar.apps.search.context_processors.search_form',
-                            'oscar.apps.promotions.context_processors\
-                            .promotions',
-                            'oscar.apps.checkout.context_processors.checkout',
-                            'oscar.apps.customer.notifications.\
-                            context_processors.notifications',
-                            'oscar.core.context_processors.metadata',
-                        ],
-                    },
-                },
-            ]
+        installedAppsSettings = {
+            'INSTALLED_APPS': [
+                'django.contrib.admin', 
+                'django.contrib.auth', 
+                'django.contrib.contenttypes', 
+                'django.contrib.sessions', 
+                'django.contrib.messages', 
+                'django.contrib.staticfiles', 
+                'django.contrib.sites', 
+                'django.contrib.flatpages', 
+                'compressor', 'widget_tweaks', 
+                'oscar', 'oscar.apps.analytics', 
+                'oscar.apps.checkout', 'oscar.apps.address', 
+                'oscar.apps.shipping', 'oscar.apps.catalogue', 
+                'oscar.apps.catalogue.reviews', 'oscar.apps.partner', 
+                'oscar.apps.basket', 'oscar.apps.payment', 'oscar.apps.offer', 
+                'oscar.apps.order', 'oscar.apps.customer', 
+                'oscar.apps.promotions', 'oscar.apps.search', 
+                'oscar.apps.voucher', 'oscar.apps.wishlists', 
+                'oscar.apps.dashboard', 'oscar.apps.dashboard.reports', 
+                'oscar.apps.dashboard.users', 'oscar.apps.dashboard.orders', 
+                'oscar.apps.dashboard.promotions', 
+                'oscar.apps.dashboard.catalogue', 
+                'oscar.apps.dashboard.offers', 'oscar.apps.dashboard.partners',
+                'oscar.apps.dashboard.pages', 'oscar.apps.dashboard.ranges', 
+                'oscar.apps.dashboard.reviews', 'oscar.apps.dashboard.vouchers', 
+                'oscar.apps.dashboard.communications', 
+                'oscar.apps.dashboard.shipping', 'haystack', 'treebeard', 
+                'sorl.thumbnail', 'django_tables2'],
         }
-        self.assertEqual(settingsContent['TEMPLATES'],
-                         templatesSettings['TEMPLATES'])
+        self.assertEqual(settingsContent['INSTALLED_APPS'],
+                         installedAppsSettings['INSTALLED_APPS'])
 
 if __name__ == "__main__":
     testAttachSettings = TestAttachSettings()
